######################################################################
# Distribution plot of the time between diagnosis and depopulation
# in days.
# Data from JPVS p.173
######################################################################

diagdep.plot <- function(makeEps=0) {
  names <- c("<0","0","1","2","3","4","5","6","7",">7")
  data <- c(3.5,10.75,58.5,20,4.75,1.5,0.25,0.5,0.5,0.25)

  if (makeEps) {
    hoehlehalfA4plot(paste(cvsPath,"tex/SIRmcmc/figs/diagdep.eps",sep=""))
    barplot(data,names.arg=names,ylim=c(0,60),ylab="Frequency in % (n=429)",xlab="")
    mydevoff()
  } else {
    barplot(data,names.arg=names,ylim=c(0,60),ylab="Frequency in % (n=429)",xlab="")
  }
}

######################################################################
#
# Show Y(t) of the epidemic
######################################################################

csf.traj.Y <- function(makeEps=0) {
  #xnames <- c("96-51","96-52")
  #for (i in 1:52) {
  #  if (i<10) {zero <- "0"} else {zero<- ""}
  #  xnames <- append(xnames,paste("97-",zero,i,sep=""))
  #}
  #xnames <<- append(xnames,c("98-01","98-02","98-03","98-04"))

  
  if (makeEps) {
    hoehlehalfA4plot(paste(cvsPath,"tex/SIRmcmc/figs/csf-trajY.eps",sep=""))
    plot(1:58,csfv$I,type="s",ylab="Number of infected",xlab="No. of weeks after first infection")
    mydevoff()
  } else {
    plot(1:58,csfv$I,type="s",ylab="Number of infected",xlab="No. of weeks after first infection")
  }
}


###################################################
#
# Tak CSF data of number of detection within a week
# and create a dataset of it denoting recovery times.
#
####################################################

csfv.load <- function() {
  csfv <<-  read.table("C:/user/hoehle/work/Java/SIRmcmc/csfv.txt",header=T)
}

csfv.rectimes <- function() {
  csfv.load()
  C <- csfv$C
  res <- numeric(0)
  curNo <- 1
  regimeSwitch <- numeric(4)

  #Find out, where the regime switches occur by looking at the phase
  #variable. Check for entire length except last which is NA.
  for (i in 2:(length(C)-1)) {
    if (csfv$phase[i] > csfv$phase[i-1]) {
      regimeSwitch[curNo] <- i-1
      curNo <- curNo+1
    }
  }
  regimeSwitch <<- regimeSwitch
  
  #Sample recovery times uniform within weeks based on C
  for(i in 1:length(C)) {
      res <- append(res,runif(C[i], min=(i-1), max=i))
  }
  res <- sort(res)

  # Adjust all times, so first recovery has time 0. Saved to both
  # variable and file.
  firstRecAbsTime <<- min(res)
  write(firstRecAbsTime,file = "c:/user/hoehle/work/Java/SIRmcmc/data/first-csf.txt",append=F)
  print(firstRecAbsTime)
  res <- res-firstRecAbsTime
  return(res)
}

##########################
#
# Write it to a file 
#
##########################
csfv.write <- function(regimeSwitch,firstRecAbsTime) {
  res <<- csfv.rectimes()
  print(res)
  write(c(21499,1,410,max(res)+1), file =
        "c:/user/hoehle/work/Java/SIRmcmc/data/csfv-R.txt",ncolumns=4,append=F)

  line2 <- numeric(0)
  line2 <- append(line2,"regimes")
  line2 <- append(line2,length(regimeSwitch)+1)
  prior <- c(0,0,0,0)
  line2 <- append(line2,prior)
  
  for (i in 1:length(regimeSwitch)) {
    line2 <- append(line2,regimeSwitch[i]-firstRecAbsTime)
    line2 <- append(line2,prior)
  }
  print(line2)
  write(line2,file= "c:/user/hoehle/work/Java/SIRmcmc/data/csfv-R.txt",ncolumns=26,append=T)
  write(res, file = "c:/user/hoehle/work/Java/SIRmcmc/data/csfv-R.txt",ncolumns=1,append=T)
}

csf.mcmc.anal <- function() {
    boa.chain.import("csf-mcmc", path="C:/user/hoehle/work/Java/SIRmcmc/data/", type="ASCII")
  boa.print.stats()
  boa.plot.geweke(c("csf-mcmc"),c("beta0"),bins=10)
}
  
#source(paste(cvsPath,"Java/SIRmcmc/data/csf-anal.S",sep=""))









