#!/usr/local/bin/perl

if ($ARGC != 0) {
    die "Wrong number of parameters. Syntax is \n\n" .
	"splitsim.pl <basename>" . "\n";
}

#In case there is a basename we don't use stdin but the file.
$basename = $ARGV[0];
if (!($basename eq "")) { 
    open(STDIN,"$basename.txt") || die "Couldn't open $basename.txt.\n";
}

$ifile = "$basename-I.txt";
$rfile = "$basename-R.txt";

#open(STDIN) || die "Couldn't open STDIN.\n";

open(I,">$ifile") || die "Couldn't open $ifile.\n";
open(R,">$rfile") || die "Couldn't open $rfile.\n";

$N  = 0;
$a  = 0;
$T  = 0;
$m  = 0;
#In this loop we try to find the first recovery time, which
#according to the setup in Oneill is equal to time zero.
#other times are adjusted relative to this value.
$firstRecovery = 0;
$line = 0;
$curRegime = 0;

while ($line = <STDIN>) {
    chop($line);
    #Split the line into the fields.
    #Configuration of the epidemic file is
    #time x y I/R
    ($time,$x,$y,$which) =  split(' ', $line,5); 

    #First line of epi file can be used to extract $N and $a
    if ($line == 0) {
	$N = $x;
	$a = $y;
    }

    if ($which eq "R") {
	#If its the first recovery time we are observing then
	#we save it to make all values relative to it.
	if ($firstRecovery == 0) {
	    $firstRecovery = $time;
	}
	$m++; #Counting number of recovery times.
	# Last time is put equal to the last recovery time seen so
        # far. We only operate with epidemics observed to the end!
	$T = $time-$firstRecovery+1
    } elsif ($which eq "S") {
	$regimes[$curRegime++] = $time-$firstRecovery;
    }
    $line++;
}

print "First Recovery : " . $firstRecovery . "\n";

#Print header information to the files.
print "Header: N=$N, a=$a, m=$m, T=$T\n";
print I "$N $a $m $T\n";

#####################################################
#Print lambda file together with regime info (if any)
#####################################################
print R "$N $a $m $T\n";
print R "regimes " . sprintf("%d",$curRegime+1) . " 0 0 0 0 ";
for ($i=0; $i<$curRegime; $i++) {
    print R $regimes[$i] . " 0 0 0 0 ";
}
print R "\n";
#####################################################

#Go back to beginning of stdin - i.e. reset line pointer.
seek(STDIN,0,0);  
 
while (($line = <STDIN>)) {
    #print $line . "\n";
    chop($line);
    #Split the line into the fields.
    #Configuration of the epidemic file is
    #time x y I/R
    ($time,$x,$y,$which) =  split(' ', $line,5); 
    #print "\"" . $which . "\"" . "\n";

    # If its a recovery it goes in the rfile
    if ($which eq "R") {
	# Write it with 4 decimals.
	print R sprintf("%.4f",$time-$firstRecovery)  . "\n";
    } elsif ($which eq "I") {#if its an infection we stuff it in the ifile.
	print I sprintf("%.4f",$time-$firstRecovery)  . "\n";
    } else {
	print sprintf("Switch point at time %.4f",$time-$firstRecovery) . "\n";
    }
}


close(I);
close(R);


